@@ -1,4 +1,6 @@
 import uuid
+from typing import Optional
+
 from lxml import etree
 
 
@@ -96,6 +98,17 @@ def commit(
     return make_rpc("".join(pieces), msg_id=msg_id)
 
 
+def cancel_commit(persist_id: Optional[str] = None, msg_id=None):
+    pieces = []
+    pieces.append("<cancel-commit>")
+
+    if persist_id:
+        pieces.append(f"<persist-id>{persist_id}</persist-id>")
+
+    pieces.append("</cancel-commit>")
+    return make_rpc("".join(pieces), msg_id=msg_id)
+
+
 def lock(target, msg_id=None):
     pieces = []
     pieces.append("<lock>")
